@@ -1,9 +1,9 @@
 #!/usr/bin/perl
 
 package Directory::Transactional::TXN::Nested;
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
-use Squirrel;
+use Any::Moose;
 
 use namespace::clean -except => 'meta';
 
